==> igniteui-react-charts-16.6.4.tgz: package/ES5/igr-standard-deviation-indicator.js <==
import * as tslib_1 from "tslib";
import { IgrStrategyBasedIndicator } from "./igr-strategy-based-indicator";
import { StandardDeviationIndicator } from "./StandardDeviationIndicator";
/**
 * Represents a IgxDataChartComponent Standard Deviation indicator series.
 * Default required members: High, Low, Close
*
* `IgxStandardDeviationIndicatorComponent` (SDI) measures statistical variation in stock prices or volatility. The difference between an individual security’s closing price and the average security closing price is called the dispersion. The larger the dispersion is the higher the standard deviation will be and therefore the volatility. The smaller the dispersion is (the difference between an individual closing price and the average price), the smaller the standard deviation and the lower the price volatility.
*
* Using this indicator requires setting both the `HighMemberPath`, `LowMemberPath` and `CloseMemberPath`.
*
* ```html
*  <igx-data-chart
*     width=500px
*     height=500px
*     [dataSource]="data" >
*     <igx-ordinal-time-x-axis
*         dateTimeMemberPath="TimeStamp"
*         #xAxis>
*       </igx-ordinal-time-x-axis>
*     <igx-numeric-y-axis
*        #yAxis></igx-numeric-y-axis>
*     <igx-standard-deviation-indicator
*        [xAxis]="xAxis"
*        [yAxis]="yAxis"
*        closeMemberPath="Close"
*        highMemberPath="High"
*        lowMemberPath="Low">
*      </igx-standard-deviation-indicator>
* </igx-data-chart>
* ```
*/
var IgrStandardDeviationIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(IgrStandardDeviationIndicator, _super);
    function IgrStandardDeviationIndicator(props) {
        return _super.call(this, props) || this;
    }
    IgrStandardDeviationIndicator.prototype.createImplementation = function () {
        return new StandardDeviationIndicator();
    };
    Object.defineProperty(IgrStandardDeviationIndicator.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrStandardDeviationIndicator.prototype, "period", {
        /**
         * Gets or sets the moving average period for the current StandardDeviationIndicator object.
         * The typical, and initial, value for STDEV periods is 20.
        */
        get: function () {
            return this.i.qo;
        },
        set: function (v) {
            this.i.qo = +v;
        },
        enumerable: true,
        configurable: true
    });
    return IgrStandardDeviationIndicator;
}(IgrStrategyBasedIndicator));
export { IgrStandardDeviationIndicator };

==> igniteui-react-charts-16.6.8.tgz: package/ES5/igr-standard-deviation-indicator.js <==
import * as tslib_1 from "tslib";
import { IgrStrategyBasedIndicator } from "./igr-strategy-based-indicator";
import { StandardDeviationIndicator } from "./StandardDeviationIndicator";
/**
 * Represents a IgxDataChartComponent Standard Deviation indicator series.
 * Default required members: High, Low, Close
*
* `IgrStandardDeviationIndicator` (SDI) measures statistical variation in stock prices or volatility. The difference between an individual security’s closing price and the average security closing price is called the dispersion. The larger the dispersion is the higher the standard deviation will be and therefore the volatility. The smaller the dispersion is (the difference between an individual closing price and the average price), the smaller the standard deviation and the lower the price volatility.
*
* Using this indicator requires setting both the `HighMemberPath`, `LowMemberPath` and `CloseMemberPath`.
*/
var IgrStandardDeviationIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(IgrStandardDeviationIndicator, _super);
    function IgrStandardDeviationIndicator(props) {
        return _super.call(this, props) || this;
    }
    IgrStandardDeviationIndicator.prototype.createImplementation = function () {
        return new StandardDeviationIndicator();
    };
    Object.defineProperty(IgrStandardDeviationIndicator.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrStandardDeviationIndicator.prototype, "period", {
        /**
         * Gets or sets the moving average period for the current StandardDeviationIndicator object.
         * The typical, and initial, value for STDEV periods is 20.
        */
        get: function () {
            return this.i.qq;
        },
        set: function (v) {
            this.i.qq = +v;
        },
        enumerable: true,
        configurable: true
    });
    return IgrStandardDeviationIndicator;
}(IgrStrategyBasedIndicator));
export { IgrStandardDeviationIndicator };
